

.. image:: https://travis-ci.org/sonofeft/IntroRL.svg?branch=master
    :target: https://travis-ci.org/sonofeft/IntroRL

.. image:: https://img.shields.io/pypi/v/IntroRL.svg
    :target: https://pypi.python.org/pypi/introrl
        
.. image:: https://img.shields.io/pypi/pyversions/IntroRL.svg
    :target: https://wiki.python.org/moin/Python2orPython3

.. image:: https://img.shields.io/pypi/l/IntroRL.svg
    :target: https://pypi.python.org/pypi/introrl

.. note::
    This project is in the early stages of development.

**IntroRL** Provides A Framework For Exploring Reinforcement Learning.

It is based on the textbook
`"Reinforcement Learning An Introduction" <https://www.amazon.com/Reinforcement-Learning-Introduction-Adaptive-Computation/dp/0262039249>`_ 
By Sutton & Barto.

The textbook is also available in `PDF format at the authors' site. <http://incompleteideas.net/book/the-book-2nd.html>`_

This documentation of **IntroRL** is organized around the chapter structure of the Sutton & Barto textbook.

Many of the examples and figures are reproduced here in order to validate the **IntroRL** code.

There is another site by `Shangtong Zhang <https://github.com/ShangtongZhang/reinforcement-learning-an-introduction>`_
that was of great help to me and which covers many areas of the textbook not covered here.
   
===================================================================================================================================================


See the Code at: `<https://github.com/sonofeft/IntroRL>`_

See the Docs at: `<http://introrl.readthedocs.org/en/latest/>`_

See PyPI page at:`<https://pypi.python.org/pypi/introrl>`_


